The R package starnet implements stacked elastic net regression.
The elastic net generalises ridge and lasso regularisation.
Instead of fixing or tuning the mixing parameter alpha,
we combine multiple alphas by stacked generalisation.
Maintainer: Armin Rauschenberger armin.rauschenberger@uni.lu
Use function starnet for model fitting.
Type library(starnet) and then ?starnet or
help("starnet)" to open its help file.
See the vignette for further examples.
Type vignette("starnet") or browseVignettes("starnet")
to open the vignette.
A Rauschenberger, E Glaab, and MA van de Wiel (2021). "Predictive and interpretable models via the stacked elastic net". Bioinformatics. 37(14):2012-2016. tools:::Rd_expr_doi("10.1093/bioinformatics/btaa535"). armin.rauschenberger@uni.lu
Useful links: